TitlePane Test

# Bidi TitlePane Test

# Title pane with tooltip, textDir == 'auto'

Arabic, Hebrew, Urdu, and Farsi (Persian) are written from right to left, while numbers and segments of Latin (or Cyrillic or Greek) text are embedded in this text from left to right. The dual directionality aspects of such bidirectional (bidi) text are posing challenges to the way this text is processed and presented in computer applications.

# Title pane, textDir == 'rtl'

The Unicode Bidirectional Algorithm, which is commonly used for preparation of Bidi text for display, is not capable to reliably identify the natural base text direction for a given text. Only a human reader can unfailingly recognize the natural base text direction for a given text. Support for enforcing the base text direction is provided out of the box by most platforms / technologies, but very often the default settings do not guarantee proper display of English and Arabic/Hebrew text in the same application. See for reference: http://w3-03.ibm.com/globalization/page/publish/4353
Errors: ?
Failures: ?